@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief f[^̓ǂݏo(PC)
+  \brief f[^̓ǂݏ([J)
 
   \author Satofumi KAMIMURA
 
