@@ -29,12 +29,17 @@ class AccessSettings {
 public:
   std::vector<std::string> user_names_; //!< [U
   std::vector<std::string> user_password_; //!< pX[h
+  std::vector<std::string> server_address_; //!< T[oAhX
 
   std::vector<int> convert_mode_; //!< ̓[h
-  std::vector<size_t> practice_num_;         //!< K
+  std::vector<size_t> practice_num_; //!< K
+
+  std::vector<int> practice_mode_; //!< K[h
+  std::vector<int> data_send_;     //!< f[^M
 
   std::vector<int> music_volume_; //!< Ȃ̃{[
   std::vector<int> effect_volume_; //!< ʉ̃{[
+  std::vector<std::string> voice_resource_; //!< rݏグ\[X
 
   size_t user_index_;           //!< I𒆂̃[UCfbNX
 
