@@ -15,6 +15,7 @@
 
 namespace beego {
   class TtfResource;
+  class TextProperty;
 
   class ButtonComponent : public ComponentInterface {
     ButtonComponent(const ButtonComponent& rhs);
@@ -31,12 +32,13 @@ namespace beego {
     ~ButtonComponent(void);
 
     void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
-			size_t ticks);
+                        size_t ticks);
     void setPosition(const SDL_Rect* position);
     void getPosition(SDL_Rect* position);
     size_t getWidth(void);
     size_t getHeight(void);
-    void applyInput(const InputEvent& event);
+    void applyInput(const InputEvent& event,
+                    std::vector<SDL_Rect>& applied_rects);
     void registerLayer(Layer* layer);
 
     // !!! 傫̈ႤT[tFXo^ꍇɂ́Aǂ̂ȁH
@@ -46,44 +48,37 @@ namespace beego {
     // !!!   - T[tFX̊ʒuw肷
     // !!!     - SAAEA㉺AE
 
-    // !!! `T[tFXTCYƁA̔zuItZbgwł΁AꂾH
+    // !!! `T[tFXTCYƁA̔zuItZbgw\ɂ
 
     // T[tFXo^
     void registerNormalSurface(Surface surface,
-			       int x_offset =0, int y_offset = 0);
+                               int x_offset =0, int y_offset = 0);
 
     // T[tFXo^
     void registerPressedSurface(Surface surface,
-				int x_offset =0, int y_offset = 0);
+                                int x_offset =0, int y_offset = 0);
 
     // tH[JXT[tFXo^
     void registerFocusedSurface(Surface surface,
-				int x_offset =0, int y_offset = 0);
+                                int x_offset =0, int y_offset = 0);
+
+    Surface getNormalSurface(void);
 
     void showNormalSurface(void);
     void showPressedSurface(void);
     void showFocusedSurface(void);
 
-    // !!! \T[tFXA[Uw肷邩AL[Ŏw肷邩AI
+    // !!! \T[tFX[Uw肷邩AL[Ŏw肷邩AI
 
+    bool isChanged(void);
     bool isDecided(void);
+    void setDecided(void);
     void releaseDecided(void);
 
-    static void createSimpleButton(boost::shared_ptr<ButtonComponent>& button,
-				   TtfResource* font, const Uint16* text,
-				   size_t size, Uint32 fore, Uint32 back,
-				   size_t selected_size,
-				   Uint32 selected_fore,
-				   Uint32 selected_back,
-				   bool transparent = false);
-
-    static void createSimpleButton(boost::shared_ptr<ButtonComponent>& button,
-				   TtfResource* font, const char* text,
-				   size_t size, Uint32 fore, Uint32 back,
-				   size_t selected_size,
-				   Uint32 selected_fore,
-				   Uint32 selected_back,
-				   bool transparent = false);
+    static void createButton(boost::shared_ptr<ButtonComponent>& button,
+                             const TextProperty& normal,
+                             const TextProperty& selected,
+                             const TextProperty& pressed);
   };
 };
 
