@@ -88,8 +88,8 @@ CommonResources::~CommonResources(void) {
 
 
 CommonResources* CommonResources::getObject(const char* savedir) {
-  static CommonResources obj(savedir);
-  return &obj;
+  static CommonResources singleton(savedir);
+  return &singleton;
 }
 
 
@@ -475,10 +475,5 @@ std::vector<std::string> CommonResources::getAllVoiceResources(void) {
 
 std::string CommonResources::getVoiceResource(void) {
   size_t user_index = settings_->user_index_;
-
-  if (user_index == 0) {
-    return "";
-  } else {
-    return settings_->voice_resource_[user_index];
-  }
+  return settings_->voice_resource_[user_index];
 }
