@@ -8,8 +8,6 @@
   \author Satofumi KAMIMURA
 
   $Id$
-
-  \todo oϐ̖𓝈ꂷ
 */
 
 #include "TypingTextConverter.h"
@@ -45,30 +43,29 @@ class CommonResources {
  public:
   //////////////////////////////////////////////////////////////////////
   // GUI 
-  beego::GuiManager* gui;       //!< GUI Ǘ
-  beego::Layer* front_layer;    //!< OiC[
-  beego::Layer* back_layer;     //!< wiC[
-  boost::shared_ptr<beego::ConsolePanelComponent> debug; //!< fobO\p
+  beego::GuiManager* gui_;       //!< GUI Ǘ
+  beego::Layer* front_layer_;    //!< OiC[
+  beego::Layer* back_layer_;     //!< wiC[
+  boost::shared_ptr<beego::ConsolePanelComponent> debug_; //!< fobO\p
 
-  beego::Component back_label;  //!< wi摜
-  beego::TtfResource* font;     //!< tHg\[X
-  beego::Component menu_icon;   //!< j[ACR
-  beego::Component user_label;  //!< [U
+  beego::Component back_label_;  //!< wi摜
+  beego::TtfResource* font_;     //!< tHg\[X
+  beego::Component menu_icon_;   //!< j[ACR
+  beego::Component user_label_;  //!< [U
 
-  beego::InputHandler* input;   //!< ̓nh
-  boost::shared_ptr<beego::InputReceiveComponent> input_receiver; //!< ͎M
+  beego::InputHandler* input_;   //!< ̓nh
+  boost::shared_ptr<beego::InputReceiveComponent> input_receiver_; //!< ͎M
 
   //////////////////////////////////////////////////////////////////////
   // VXe
-  TypingRecorder* recorder;     //!< ^CsŐL^
-  std::vector<int> waka_order;  //!< â̕
-
+  TypingRecorder* recorder_;     //!< ^CsŐL^
+  std::vector<int> waka_order_;  //!< â̕
   VoicePlayer* voice_;           //!< rݏグ
 
   //////////////////////////////////////////////////////////////////////
   // ݒ
-  std::string savedir_;            //!< f[^̕ۑfBNg
-  AccessSettings* settings;        //!< ݒ
+  std::string savedir_;             //!< f[^̕ۑfBNg
+  AccessSettings* settings_;        //!< ݒ
 
   ~CommonResources(void);
 
@@ -109,20 +106,26 @@ class CommonResources {
     \brief ݂̃[U̎擾
   */
   const char* getUserName(void) const;
+  int getUserIndex(void);
+
+  const char* getPassword(void) const;
+
+  void changeUserIndex(size_t index);
 
   /*!
     \brief [U̍폜
 
     \brief user_name [i] ǉ[U
   */
-  void addUser(const char* user_name, const char* password);
+  void addUser(const char* user_name, const char* password,
+               const char* address);
 
   /*!
     \brief w胆[U̍폜
 
     \brief user_name [i] 폜[Uԍ
   */
-  void deleteUser(int  user_index);
+  void deleteUser(int user_index);
 
   void updateUserLable(void);
 
@@ -139,10 +142,20 @@ class CommonResources {
   void haltMusic(void);
   void updateSoundVolume(int percent);
 
-  void playEffect(int id);
+  bool registerEffect(int id, const char* file);
+  int playEffect(int id);
   bool nowEffectPlaying(void);
-  void stopEffect(void);
+  void stopEffect(int id = -1);
   void updateEffectVolume(int percent);
+
+  std::string getServerName(void);
+  std::string getServerAddress(void);
+
+  int getPracticeWakaNo(void);
+  bool isSendData(void);
+
+  std::vector<std::string> getAllVoiceResources(void);
+  std::string getVoiceResource(void);
 };
 
 #endif /* !COMMON_RESOURCES_H */
