@@ -25,7 +25,7 @@ namespace beego {
   public:
     virtual ~ComponentInterface() {}
     virtual void addSurfaceList(SurfaceList& surfaces,
-				const SDL_Rect* area, size_t ticks) = 0;
+                                const SDL_Rect* area, size_t ticks) = 0;
     virtual void setPosition(const SDL_Rect* position) = 0;
 
     // !!! SDL_Rect getPosition(void) ɕύX邩ȁH
@@ -33,7 +33,11 @@ namespace beego {
 
     virtual size_t getWidth(void) = 0;
     virtual size_t getHeight(void) = 0;
-    virtual void applyInput(const InputEvent& event) = 0;
+    virtual void applyInput(const InputEvent& event,
+                            std::vector<SDL_Rect>& applied_rects) = 0;
+
+    // !!! uzuv̈Ӗ܂ރ\bhɒu
+    // !!! Ƃ͕ۗ
     virtual void registerLayer(Layer* layer) = 0;
   };
 };
