@@ -26,7 +26,6 @@ bool beego::createDirectory(const char* directory) {
   if (directory[n - 1] == '/') {
     dir_path = dir_path.substr(0, n - 1);
   }
-
   std::string next_create = dir_path.substr(0, dir_path.find_last_of('/'));
 
   // !!! ݌邩AmFׂ
@@ -34,13 +33,14 @@ bool beego::createDirectory(const char* directory) {
     return true;
   }
 
-  createDirectory(next_create.c_str());
-
   // fBNg̍쐬
 #ifndef MSC
-  fprintf(stderr, "%s, %s\n", directory, dir_path.c_str());
   return (mkdir(dir_path.c_str(), 0755) == 0) ? true : false;
 #else
   return (_mkdir(dir_path.c_str()) == 0) ? true : false;
 #endif
+
+  if (! createDirectory(next_create.c_str())) {
+    return false;
+  }
 }
