@@ -7,7 +7,6 @@
   $Id$
 
   \todo F؉摜Aǂ߂Ȃ
-  \todo Step.4 ̐l̕\͗vȂ
   \todo PC ̃[UƏdȂAʂ
   \todo TextInput AhX͉\ɂ
 */
@@ -113,7 +112,7 @@ struct CreateUser::pImpl {
       selector_->addItem("1");
       selector_->addItem("2");
       selector_->addItem("3");
-      selector_->addItem("4");
+      //selector_->addItem("4");
       selector_->setItemsOffset(NormalSize/2);
       selector_->disableInput();
 
@@ -133,7 +132,11 @@ struct CreateUser::pImpl {
       removeComponents();
 
       // ZN^ʒu̒
-      selector_->setSelected(static_cast<int>(now_progress_));
+      if (now_progress_ >= 3) {
+        selector_->setSelected(static_cast<int>(SelectComponent::NotSelected));
+      } else {
+        selector_->setSelected(static_cast<int>(now_progress_));
+      }
 
       SDL_Rect position;
       if (now_progress_ > 0) {
@@ -1117,6 +1120,7 @@ void CreateUser::run(void) {
 
   GuiManager* gui = pimpl->common_->gui_;
   InputHandler& input = *pimpl->common_->input_;
+  InputEvent input_event;
   bool quit = false;
   bool escape_pressed = false;
   while (quit == false) {
@@ -1125,8 +1129,9 @@ void CreateUser::run(void) {
     pimpl->scheduler_.update();
 
     // I
-    quit |= pimpl->scheduler_.isTerminated() ||
-      pimpl->back_button_->isDecided();
+    input.updateInputEvent(input_event);
+    quit |= pimpl->scheduler_.isTerminated() |
+      pimpl->back_button_->isDecided() | input_event.right_clicked;
     input.update_all();
     gui->update();
     if (input.haveQuitEvent()) {
