@@ -13,6 +13,9 @@
 #include <memory>
 
 
+/*!
+  \brief [U쐬
+*/
 class CreateUser {
   CreateUser(const CreateUser& rhs);
   CreateUser& operator = (const CreateUser& rhs);
@@ -24,6 +27,9 @@ public:
   CreateUser(void);
   ~CreateUser(void);
 
+  /*!
+    \brief N
+  */
   void run(void);
 };
 
