@@ -17,6 +17,7 @@
 #include "DrawsDefinition.h"
 #include "CommonResources.h"
 #include "ResourceDefinition.h"
+#include "UpdateUtils.h"
 #include "PracticeMenu.h"
 #include "NetworkMenu.h"
 #include "ViewHistory.h"
@@ -25,7 +26,6 @@
 #include "user_bmp.h"
 #include "white_bmp.h"
 #include "AccessSettings.h"
-#include "GuiManager.h"
 #include "Layer.h"
 #include "SdlSurface.h"
 #include "MultiSurface.h"
@@ -35,7 +35,6 @@
 #include "ButtonComponent.h"
 #include "MenuComponent.h"
 #include "ComboBoxComponent.h"
-#include "InputHandler.h"
 #include "CreateSurfaceFromArray.h"
 #include "SdlUtils.h"
 #include "Delay.h"
@@ -225,8 +224,7 @@ void FirstMenu::run(void) {
   // y̍Đ
   pimpl->common_->setNextMusic(BackMusic_1);
 
-  GuiManager* gui = pimpl->common_->gui_;
-  InputHandler& input = *pimpl->common_->input_;
+  UpdateUtils updater(pimpl->common_);
   bool quit = false;
   while (quit == false) {
 
@@ -288,9 +286,7 @@ void FirstMenu::run(void) {
       pimpl->placeComponents();
     }
 
-    input.update_all();
-    gui->update();
-    quit |= input.haveQuitEvent() | input.isReleased(SDLK_ESCAPE);
+    quit |= updater.update();
     delay(1);
   }
 }
