@@ -42,10 +42,13 @@ namespace beego {
 
     // !!! w肷܂ł́A
     void setBackgroundColor(Uint32 color);
+    void setForeColor(Uint32 color);
 
     void drawTitle(const TextProperty& title);
-    void registerLine(std::vector<Grid<double> >& points, Uint32 color);
+    void registerLine(std::vector<Grid<double> >& points, Uint32 color,
+                      TextProperty* text = NULL);
     void create(size_t width, size_t height, TtfResource* font);
+    void createLegend(int x, int y, Uint32 fore, Uint32 back);
     void clear(void);
   };
 };
