@@ -26,6 +26,10 @@ namespace beego {
     bool left_released;
     bool left_pressing;
 
+    bool right_clicked;
+    bool right_released;
+    bool right_pressing;
+
     class InputKey {
     public:
       SDLKey sym_;
@@ -45,7 +49,8 @@ namespace beego {
 
     InputEvent(void)
       : mx(0), my(0), mouse_moved(false), wheels(0),
-        left_clicked(false), left_released(false), left_pressing(false) {
+        left_clicked(false), left_released(false), left_pressing(false),
+        right_clicked(false), right_released(false), right_pressing(false) {
     }
 
     static bool isPressed(const InputEvent& event, SDLKey key);
