@@ -17,6 +17,7 @@
 namespace beego {
   /*!
     \brief Label R|[lgNX
+
     \todo LogManager Ήɂ
   */
   class LabelComponent : public ComponentInterface {
@@ -32,12 +33,13 @@ namespace beego {
     ~LabelComponent(void);
 
     void addSurfaceList(SurfaceList& surfaces, const SDL_Rect* area,
-			size_t ticks);
+                        size_t ticks);
     void setPosition(const SDL_Rect* position);
     void getPosition(SDL_Rect* position);
     size_t getWidth(void);
     size_t getHeight(void);
-    void applyInput(const InputEvent& event);
+    void applyInput(const InputEvent& event,
+                    std::vector<SDL_Rect>& applied_rects);
     void registerLayer(Layer* layer);
   };
 };
