@@ -29,6 +29,9 @@ namespace beego {
     LockGuard(const LockGuard& rhs);
     LockGuard& operator = (const LockGuard& rhs);
 
+    void* operator new (size_t);
+    void* operator new[] (size_t);
+
     struct pImpl;
     const std::auto_ptr<pImpl> pimpl;
 
