@@ -10,11 +10,7 @@
 #include "MixerInit.h"
 #include "SdlAudioInit.h"
 #include "LogManager.h"
-#ifdef MSC
-#include "SDL_win.h"
-#else
 #include <SDL_mixer.h>
-#endif
 #include <stdlib.h>
 #include <string>
 
@@ -27,9 +23,6 @@ using namespace beego;
   \todo Mix ̎gȂ
 */
 struct MixerInit::pImpl : private SdlAudioInit {
-  enum {
-    ChannelNum = 8,
-  };
   static bool initialized;
   static void cleanup(void) {
     Mix_AllocateChannels(0);
@@ -42,16 +35,16 @@ struct MixerInit::pImpl : private SdlAudioInit {
 
     if (initialized == false)  {
       if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY,
-			MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 1024) < 0) {
-	// OL^
-	LogManager* log = LogManager::getObject();
-	std::string message = "Mixer_Init(): " + std::string(Mix_GetError());
-	log->write(LogManager::Error, message.c_str());
-	return;
+                        MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS, 1024) < 0) {
+        // OL^
+        LogManager* log = LogManager::getObject();
+        std::string message = "Mixer_Init(): " + std::string(Mix_GetError());
+        log->write(LogManager::Error, message.c_str());
+        return;
       }
       atexit(Mix_CloseAudio);
 
-      Mix_AllocateChannels(pImpl::ChannelNum);
+      Mix_AllocateChannels(ChannelNum);
       atexit(cleanup);
       initialized = true;
     }
