@@ -77,6 +77,10 @@ bool PlainTextConverter::escapePressed(void) {
 
 
 bool PlainTextConverter::deleteBack(void) {
+  if (pimpl->inputed_text.empty()) {
+    return false;
+  }
+
   pimpl->inputed_text.pop_back();
   return true;
 }
