@@ -18,6 +18,7 @@
 #include "GuiManager.h"
 #include "Layer.h"
 #include "InputHandler.h"
+#include "InputEvent.h"
 #include "SdlSurface.h"
 #include "SwitchSurface.h"
 #include "TextProperty.h"
@@ -413,6 +414,7 @@ void RemoveUser::run(void) {
 
   GuiManager* gui = pimpl->common_->gui_;
   InputHandler& input = *pimpl->common_->input_;
+  InputEvent input_event;
   bool quit = false;
   bool escape_pressed = false;
   while (quit == false) {
@@ -421,8 +423,9 @@ void RemoveUser::run(void) {
     pimpl->scheduler_.update();
 
     // I
+    input.updateInputEvent(input_event);
     quit |= pimpl->scheduler_.isTerminated() ||
-      pimpl->back_button_->isDecided();
+      pimpl->back_button_->isDecided() | input_event.right_clicked;
     gui->update();
     input.update_all();
     if (input.haveQuitEvent()) {
