@@ -490,6 +490,7 @@ void ShimonokuPractice::run(void) {
 
   GuiManager* gui = pimpl->common_->gui_;
   InputHandler& input = *pimpl->common_->input_;
+  InputEvent input_event;
   bool quit = false;
   bool escape_pressed = false;
   while (quit == false) {
@@ -498,7 +499,9 @@ void ShimonokuPractice::run(void) {
     pimpl->scheduler_.update();
 
     // I
-    quit |= pimpl->scheduler_.isTerminated();
+    input.updateInputEvent(input_event);
+    quit |= pimpl->scheduler_.isTerminated() | input_event.right_clicked;
+
     input.update_all();
     gui->update();
     if (input.haveQuitEvent()) {
