@@ -34,11 +34,11 @@ namespace beego {
     ~TextFadeSurface(void);
 
     void draw(std::vector<SDL_Rect>& update_rects,
-              const SDL_Rect* pos, const SDL_Rect* area, size_t ticks);
+              const SDL_Rect* pos, const SDL_Rect* area);
     size_t getWidth(void);
     size_t getHeight(void);
     void forceSetChanged(void);
-    bool isChanged(void);
+    bool isChanged(size_t ticks);
     bool isTransparent(void);
 
     void setFadeMode(FadeMode mode, size_t width);
