@@ -14,12 +14,11 @@
 #include "CommonResources.h"
 #include "CreateUser.h"
 #include "RemoveUser.h"
-#include "GuiManager.h"
+#include "UpdateUtils.h"
 #include "Layer.h"
 #include "TextProperty.h"
 #include "TextSurface.h"
 #include "LabelComponent.h"
-#include "InputHandler.h"
 #include "ButtonComponent.h"
 #include "MenuComponent.h"
 #include "SdlUtils.h"
@@ -105,8 +104,7 @@ void UserMenu::run(void) {
   // [U̕\
   //pimpl->common_->draw
 
-  GuiManager* gui = pimpl->common_->gui_;
-  InputHandler& input = *pimpl->common_->input_;
+  UpdateUtils updater(pimpl->common_);
   bool quit = false;
   while (quit == false) {
 
@@ -140,9 +138,7 @@ void UserMenu::run(void) {
       pimpl->menu_->releaseDecided();
     }
 
-    input.update_all();
-    gui->update();
-    quit |= input.haveQuitEvent() | input.isReleased(SDLK_ESCAPE);
+    quit |= updater.update();
     delay(1);
   }
 }
