@@ -11,6 +11,8 @@
 */
 
 #include <memory>
+#include <string>
+#include <vector>
 
 
 class VoicePlayer {
@@ -25,7 +27,9 @@ public:
   VoicePlayer(const char* directory);
   ~VoicePlayer(void);
 
-  bool checkCd(void);
+  std::vector<std::string> getResources(void);
+  void setMute(void);
+  bool checkResource(std::string resource = "");
   void play(size_t id);
   void stop(void);
 };
