@@ -6,7 +6,15 @@
 
   $Id$
 
-  \todo SDL_net, SDL_image, SDL_mixer, SDL_ttf Ȃǂ̌o܂K؂ɏ
+  \todo -W tŃRpCʉ߂悤ɂ
+
+  \todo {[́AǂłύXł悤ɂ
+  \todo tXN[̃L[𔽉f
+  \todo Aj[VACR̃WM[C
+  \todo }EXŖ߂ƂɁAL[삪㏑Ă܂̂ȂƂ
+  \todo I܂H Yes/No ̍ڂH
+  \todo j[̑Jڒ̃J[\Ńj[ڂɈړ̂A}
+  \todo TextProperty  LabelComponent NXׂH
   \todo Ctrl ƁA\ȃL[͂ɂĂ̐\ƂH
   \todo lbg[NΐA̎
   \todo ڂύX閈ɁAʉ炷
@@ -16,9 +24,13 @@
 */
 
 #include "hyakutyping.h"
+#include "hyakutyping_bmp.h"
+#include "icon_mask.h"
 #include "CommonResources.h"
 #include "ResourceDefinition.h"
+#include "VoicePlayer.h"
 #include "FirstMenu.h"
+#include "CreateSurfaceFromArray.h"
 #include "SdlVideo.h"
 
 using namespace beego;
@@ -67,6 +79,10 @@ int main(int argc, char *argv[]) {
   // ʂ̏
   SdlVideo video;
   video.setCaption(PACKAGE_STRING);
+  SDL_Surface* icon = createSurface(hyakutyping_bmp,
+                                    hyakutyping_bmp_width,
+                                    hyakutyping_bmp_height);
+  video.setIcon(icon, icon_mask);
   video.setFullscreenMode(fullscreen);
   if (! video.show()) {
     printf("SdlVideo::show(): %s\n", video.what());
@@ -91,6 +107,9 @@ int main(int argc, char *argv[]) {
   // y̏
   if (! music_mute) {
     common->initializeMusic();
+  } else {
+    // rݏグsȂ悤ɂ
+    common->voice_->setMute();
   }
 
   // j[ʂ̌Ăяo
