@@ -29,6 +29,16 @@
 #endif
 const char*const VersionText = "version " PACKAGE_VERSION; //!< o[W
 
+#ifndef MAJOR_VERSION
+#define MAJOR_VERSION "X"
+#endif
+#ifndef MINOR_VERSION
+#define MINOR_VERSION "X"
+#endif
+#ifndef MICRO_VERSION
+#define MICRO_VERSION "X"
+#endif
+
 
 // ^Cg
 #ifndef PACKAGE_STRING
